@@ -471,6 +471,8 @@ class QueueMonitor:
                      log("%d newJobs" % (nNewJobs))
                   if nOrphanJobs > 0:
                      log("%d orphanJobs" % (nOrphanJobs))
+                  if nNewJobs+nOrphanJobs > 0:
+                     break
                else:
                   self.cleanup()
                   log("%s empty job monitor stopped" % (self.siteDesignator))
